/******************************************************************************
* Macro to test XPS command line                                              *
*                                                                             *
* Author: Christian Stratowa, Vienna, Austria    .                            *
* Created: 15 Mar 2003                             Last modified: 07 Feb 2010 *
******************************************************************************/
//
///////////////////////////
//
// in new root session(s):
//     > .L macro4XPSTest3.C 
//     > Init() 
//     > RMATest3("tmp_Test3A_rma", "DataTest3_cel.root")
//     > RMATest3("tmp_Test3B_rma", "DataTest3_52600a_cel.root")
//
///////////////////////////

//______________________________________________________________________________
void Init(const char *libxps = "")
{
   TString xps = TString(libxps);
   if (strcmp(libxps, "") == 0) {xps = TString(gSystem->pwd()); xps += "/src/xps.so";}

// load libraries
   gSystem->Load("libGui.so");
   gSystem->Load(xps.Data());
}//Init

//______________________________________________________________________________
void RMATest3(const char *filename   = "Test3_rma",
              const char *datafile   = "DataTest3_cel.root",
              const char *filedir    = "",
              const char *schemefile = "")
{
   TString dir = TString(filedir);
   TString scm = TString(schemefile);
   if (strcmp(filedir,    "") == 0) {dir = TString(gSystem->pwd());}
   if (strcmp(schemefile, "") == 0) {scm = TString(gSystem->pwd()); scm += "/SchemeTest3.root";};
cout << "filedir= " << dir.Data() << endl;
cout << "schemefile= " << scm.Data() << endl;

// create new preprocessing manager
   XPreProcessManager *manager = new XPreProcessManager("PreProcessManager");

// initialize preprocessing algorithms
   manager->Initialize("GeneChip");

// initialize backgrounder
//   manager->InitAlgorithm("selector","probe","pmonly", 0, 0);
//   manager->InitAlgorithm("backgrounder","rma","pmonly:epanechnikov",0, 1,16384);

// initialize normalizer
   manager->InitAlgorithm("selector","probe","pmonly", 0);
   manager->InitAlgorithm("normalizer","quantile","transcript:together:none:0",0, 1,0.0);

// initialize expressor
   manager->InitAlgorithm("selector","probe","pmonly", 0);
   manager->InitAlgorithm("expressor","medianpolish","log2",0,3,10,0.01,1.0);

// create new root data file 
   manager->New(filename,dir,"GeneChip");

// open root scheme file
   manager->OpenSchemes(scm);

// add trees for preprocessing
   TString tree = dir; tree += "/"; tree += datafile; tree += "/DataSet/*.cel";
cout << "tree= " << tree << endl;
   manager->AddTree("RMASet", tree.Data());

// preprocess expression values and store as trees in new file
   manager->Preprocess("RMASet", "preprocess");

// cleanup
   manager->Close();
   delete manager;
}//RMATest3

//______________________________________________________________________________

